@@ -138,7 +138,7 @@ def run(config):
   print "Creating temp directory"
   if not dry_run:
     mount_dir_path = mkdtemp()
-    fdisk_output_path = mkstemp()
+    fdisk_output_path = mkstemp()[1]
   else:
     mount_dir_path = "/tmp/a_generated_directory"
     fdisk_output_path = "/tmp/a_generated_file"
@@ -280,6 +280,9 @@ def run(config):
     print "Deleting temp directory: %s" % mount_dir_path
     if not dry_run:
       shutil.rmtree(mount_dir_path)
+    print "Deleting temp file: %s" % fdisk_output_path
+    if not dry_run:
+      os.remove(fdisk_output_path)
 
   # Copying
   if not config.no_usb:
